@@ -6,10 +6,10 @@ from typing import Any
 from vstools import core, vs
 
 from ..abstract import Antialiaser, DoubleRater, SingleRater, SuperSampler, _Antialiaser
-from .nnedi3 import NNEDI3
+from . import nnedi3
 
 __all__ = [
-    'ZNEDI3', 'Znedi3', 'Znedi3SS', 'Znedi3SR', 'Znedi3DR'
+    'Znedi3', 'Znedi3DR'
 ]
 
 
@@ -22,7 +22,7 @@ class ZNEDI3(_Antialiaser):
     pscrn: int = 2
 
     def get_aa_args(self, clip: vs.VideoNode, **kwargs: Any) -> dict[str, Any]:
-        return NNEDI3.get_aa_args(self, clip, **kwargs)  # type: ignore
+        return nnedi3.NNEDI3.get_aa_args(self, clip, **kwargs)  # type: ignore
 
     def interpolate(self, clip: vs.VideoNode, double_y: bool, **kwargs: Any) -> vs.VideoNode:
         interpolated = core.znedi3.nnedi3(
