@@ -2,10 +2,10 @@ from __future__ import annotations
 
 from math import ceil
 from pathlib import Path
-from typing import TYPE_CHECKING, Any
+from typing import TYPE_CHECKING, Any, Literal
 
 from vsexprtools import norm_expr_planes
-from vskernels import Catrom, Scaler, ScalerT, Spline144
+from vskernels import Catrom, NoScale, Scaler, ScalerT, Spline144
 from vsmasktools import EdgeDetect, EdgeDetectT, Prewitt, ScharrTCanny
 from vsrgtools import RepairMode, box_blur, contrasharpening_median, median_clips, repair, unsharp_masked
 from vstools import (
@@ -14,7 +14,7 @@ from vstools import (
 )
 
 from .abstract import Antialiaser, SingleRater
-from .antialiasers import Eedi3, Eedi3SR, Nnedi3SR, Nnedi3SS, Znedi3
+from .antialiasers import Eedi3, Nnedi3, Znedi3
 from .enums import AADirection
 from .mask import resize_aa_mask
 
@@ -34,7 +34,7 @@ def pre_aa(
     **kwargs: Any
 ) -> vs.VideoNode:
     if isinstance(aa, Antialiaser):
-        aa = aa.copy(field=3, **kwargs)
+        aa = aa.copy(field=3, **kwargs)  # type: ignore
     else:
         aa = aa(field=3, **kwargs)
 
@@ -50,7 +50,7 @@ def pre_aa(
 def upscaled_sraa(
     clip: vs.VideoNode, rfactor: float = 1.5,
     width: int | None = None, height: int | None = None,
-    ssfunc: ScalerT = Nnedi3SS(), aafunc: SingleRater = Eedi3SR(),
+    ssfunc: ScalerT = Nnedi3(), aafunc: SingleRater = Eedi3(),
     direction: AADirection = AADirection.BOTH,
     downscaler: ScalerT = Catrom(), planes: PlanesT = 0
 ) -> vs.VideoNode:
@@ -147,8 +147,8 @@ def clamp_aa(
 ) -> vs.VideoNode:
     """
     Clamp stronger AAs to weaker AAs.
-    Useful for clamping :py:func:`upscaled_sraa` or :py:func:`Eedi3SR`
-    to :py:func:`Nnedi3SR` for a strong but more precise AA.
+    Useful for clamping :py:func:`upscaled_sraa` or :py:func:`Eedi3`
+    to :py:func:`Nnedi3` for a strong but more precise AA.
 
     :param src:         Non-AA'd source clip.
     :param weak:        Weakly-AA'd clip.
@@ -208,14 +208,14 @@ def masked_clamp_aa(
         mask = mask.std.Minimum().std.Deflate()
 
     if weak_aa is None:
-        weak_aa = Nnedi3SR(
+        weak_aa = Nnedi3(
             opencl=hasattr(core, 'nnedi3cl') if opencl is None else opencl
         )
     elif opencl is not None and hasattr(weak_aa, 'opencl'):
         weak_aa._opencl = opencl  # type: ignore[attr-defined]
 
     if strong_aa is None:
-        strong_aa = Eedi3SR(opencl=opencl is None or opencl)
+        strong_aa = Eedi3(opencl=opencl is None or opencl)
     elif opencl is not None and hasattr(strong_aa, 'opencl'):
         strong_aa._opencl = opencl  # type: ignore[attr-defined]
 
@@ -234,7 +234,7 @@ def masked_clamp_aa(
 
 def fine_aa(
     clip: vs.VideoNode, taa: bool = False,
-    singlerater: SingleRater = Eedi3SR(),
+    singlerater: SingleRater = Eedi3(),
     rep: int | RepairMode = RepairMode.LINE_CLIP_STRONG
 ) -> vs.VideoNode:
     """
@@ -276,7 +276,7 @@ if TYPE_CHECKING:
         clip: vs.VideoNode, rfactor: float = 2.0,
         mask_thr: int = 60, lmask: vs.VideoNode | EdgeDetectT = Prewitt,
         downscaler: ScalerT = SSIM,
-        supersampler: ScalerT | FSRCNNXShaderT | ShaderFile | Path = FSRCNNXShader.x56,
+        supersampler: ScalerT | FSRCNNXShaderT | ShaderFile | Path | Literal[False] = FSRCNNXShader.x56,
         antialiaser: Antialiaser = Eedi3(0.125, 0.25, vthresh0=12, vthresh1=24, field=1, sclip_aa=None),
         prefilter: Prefilter | vs.VideoNode = Prefilter.NONE, show_mask: bool = False, **kwargs: Any
     ) -> vs.VideoNode:
@@ -286,7 +286,7 @@ else:
         clip: vs.VideoNode, rfactor: float = 2.0,
         mask_thr: int = 60, lmask: vs.VideoNode | EdgeDetectT = Prewitt,
         downscaler: ScalerT | MissingT = MISSING,
-        supersampler: ScalerT | FSRCNNXShaderT | ShaderFile | Path | MissingT = MISSING,
+        supersampler: ScalerT | FSRCNNXShaderT | ShaderFile | Path | Literal[False] | MissingT = MISSING,
         antialiaser: Antialiaser = Eedi3(0.125, 0.25, vthresh0=12, vthresh1=24, field=1, sclip_aa=None),
         prefilter: Prefilter | vs.VideoNode | MissingT = MISSING, show_mask: bool = False, **kwargs: Any
     ) -> vs.VideoNode:
@@ -304,11 +304,14 @@ else:
                 'You\'re missing the "vsdenoise" package! You can install it with "pip install vsdenoise".', based_aa
             )
 
-        if downscaler is MISSING:
-            downscaler = SSIM
+        if supersampler is False:
+            supersampler = downscaler = NoScale
+        else:
+            if downscaler is MISSING:
+                downscaler = SSIM
 
-        if supersampler is MISSING:
-            supersampler = FSRCNNXShader.x56
+            if supersampler is MISSING:
+                supersampler = FSRCNNXShader.x56
 
         if prefilter is MISSING:
             prefilter = Prefilter.NONE
@@ -323,7 +326,9 @@ else:
             wclip_y = get_y(prefilter)
             check_ref_clip(clip_y, wclip_y, based_aa)
         else:
-            wclip_y = prefilter(clip_y, **kwargs)
+            wclip_y = prefilter(clip_y)
+
+        antialiaser = antialiaser.copy(**kwargs)
 
         if rfactor < 1.0:
             raise CustomOverflowError(
@@ -350,8 +355,6 @@ else:
         supersampler = Scaler.ensure_obj(supersampler, based_aa)
         downscaler = Scaler.ensure_obj(downscaler, based_aa)
 
-        mclip_up = resize_aa_mask(lmask, aaw, aah)
-
         aa = clip_y.std.Transpose()
         aa = supersampler.scale(aa, aa.width * ceil(rfactor), aa.height * ceil(rfactor))
         aa = waa = downscaler.scale(aa, aah, aaw)
@@ -366,6 +369,8 @@ else:
                 clip, antialiaser.interpolate(wclip, False, sclip=wclip), mclip
             ], 'z y x ?')
 
+        mclip_up = resize_aa_mask(lmask, aa.height, aa.width)
+
         aa = _aa_mclip(aa, waa, mclip_up.std.Transpose())
 
         aa = _aa_mclip(aa.std.Transpose(), waa.std.Transpose(), mclip_up)
